MapCameraService class

Documentation for MapCameraService

Constructors

MapCameraService()

Properties

currentZoom double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isAutoFit bool
no setter
isCenter bool
no setter
isFollowing bool
no setter
isProgrammaticMove bool
getter/setter pair
mode CameraMode
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateManualMode({Duration? autoResetDuration}) → void
Documentation for method
centerToLocation(LatLng location, {double zoom = 19.5}) Future<void>
dispose() → void
Documentation for method
droneArrival(Position position) Future<void>
Documentation for method
fitBoundsWithPadding(LatLng start, LatLng end, {bool isRerouting = false}) Future<void>
fitToRoute(Position currentPosition, LatLng destination, {bool isSimulating = false}) Future<void>
followUser(LatLng target, double heading, {bool isSimulating = false}) Future<void>
Documentation for method
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setController(GoogleMapController controller) → void
Documentation for method
setMode(CameraMode mode) → void
Documentation for method
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited